==> foundation-ui-components-1.10.0-cx130-872.1.tgz: package/src/common/card/NsLargeCard.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsImage } from '../';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsLargeCardProps = {
    title: string;
    subtitle?: string;
    intro: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    isHorizontal?: boolean;
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled((props: any) => <Box {...props} />)(({ isHorizontal }) => {
    let width = '375px',
        paddingLeft = '0px',
        justifyContent,
        fontSizeSub = '16px',
        fontSizeTitle = '26px';

    if (isHorizontal) {
        width = 'unset';
        paddingLeft = '30px';
        justifyContent = 'center';
        fontSizeSub = '16px';
        fontSizeTitle = '36px';
    }
    let direction = isHorizontal ? ('row' as 'row') : ('column' as 'column');

    return {
        display: 'flex',
        flexDirection: direction,
        position: 'relative',
        width,
        '.image': {
            width: '375px',
            height: 'auto',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            flexDirection: 'column',
            paddingLeft,
            justifyContent,
        },
        '.subtitle': {
            fontSize: fontSizeSub,
            fontWeight: '400',
            marginTop: '10px',
        },
        '.title': {
            fontSize: fontSizeTitle,
            fontWeight: '400',
            marginTop: '10px',
        },
        '.cta': {
            marginTop: '10px',
        },
    };
});

export default function NsLargeCard({
    title,
    subtitle,
    backgroundImageUrl,
    backgroundImageAlt,
    intro,
    isHorizontal,
    button,
    className,
}: NsLargeCardProps) {
    return (
        <CardContainer
            className={className}
            role="large-card"
            component="div"
            data-testid="large-card"
            isHorizontal={isHorizontal}
        >
            <NsImage alt={backgroundImageAlt} src={backgroundImageUrl} className="image" />
            <div className="content">
                <article className="subtitle">{subtitle}</article>
                <article className="title">{title}</article>
                <article className="subtitle">{intro}</article>
                {button ? <CardButton {...button} /> : null}
            </div>
        </CardContainer>
    );
}

==> foundation-ui-components-1.28.0-cx130-1216.1.tgz: package/src/common/card/NsLargeCard.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import CardButton from './CardButton';
import { NsCardButton } from './types';
import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';

type NsLargeCardProps = {
    title: string;
    subtitle?: string;
    intro: string;
    backgroundImageDetail: BynderImageDataType;
    isHorizontal?: boolean;
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled((props: any) => <Box {...props} />)(({ isHorizontal, matches }) => {
    let width = '450px',
        paddingLeft = '0px',
        justifyContent,
        fontSizeSub = '16px',
        fontSizeTitle = '26px',
        imageWidth = '100%';

    if (isHorizontal) {
        width = '600px';
        paddingLeft = '30px';
        justifyContent = 'center';
        fontSizeSub = '16px';
        fontSizeTitle = '26px';
        imageWidth = '50%';
    }
    let direction = isHorizontal ? ('row' as 'row') : ('column' as 'column');

    return {
        display: 'flex',
        flexDirection: direction,
        position: 'relative',
        width,
        '.bg-image': {
            objectFit: 'cover',
            height: '220px',
            width: imageWidth,
        },
        '.content': {
            display: 'flex',
            flexDirection: 'column',
            paddingLeft,
            justifyContent,
        },
        '.subtitle': {
            fontSize: fontSizeSub,
            fontWeight: '400',
            marginTop: '10px',
        },
        '.title': {
            fontSize: fontSizeTitle,
            fontWeight: '400',
            marginTop: '10px',
        },
        '.cta': {
            marginTop: '10px',
        },
        '@media (max-width: 768px)': {
            width: '100%',
        },
    };
});

export default function NsLargeCard({
    title,
    subtitle,
    backgroundImageDetail,
    intro,
    isHorizontal,
    button,
    className,
}: NsLargeCardProps) {
    return (
        <CardContainer
            className={className}
            role="large-card"
            component="div"
            data-testid="large-card"
            isHorizontal={isHorizontal}
        >
            <BynderMedia className="bg-image" imageDetail={backgroundImageDetail} />
            <div className="content">
                <article className="subtitle">{subtitle}</article>
                <article className="title">{title}</article>
                <article className="subtitle">{intro}</article>
                {button ? <CardButton {...button} /> : null}
            </div>
        </CardContainer>
    );
}
